==> mcptool_py-1.0.7.tar.gz: mcptool_py-1.0.7/README.md <==
<h1 align="center"> 🧨 MCPTool v1.0.7
<h3 align="center"> Pentesting tool for Minecraft </h2>
<img align="center" src="https://i.imgur.com/GqkwN7v.png" alt="MCPTool" title="MCPTool" style="max-width: 100%; height: auto;">

<h4 align="center">This project was created for educational purposes and should not be used in environments without legal authorization.</p>

# 🛠 Features
* Get information from servers
* Get usernames or uuids from players
* Get information about IP addresses
* Get information about domains
* Get random servers using Seeker API (Shodan and Web Scraping will be included soon)
* Scan IP addresses (Nmap, Qubo, Masscan and others)
* Save players connecting to servers
* Easily create proxies (cascade and velocity)
* Create a fake proxy to capture data.
* Connect to a minecraft server using the terminal
* Send commands to servers using a bot
* Connect to the RCON of a server
* Perform a brute force attack on the RCON service
* Perform a brute force attack on the user of a non-premium/semi-premium server
* Kick players with bots thanks to 'You are logged in from a different location'
* Support for multiple languages.
* Search the password of a user using the nordify api.

## 💻 Supported operating systems:

* ✅ Windows (8, 8.1, 10 and 11)
* ✅ Linux
* ✅ Termux
* ✅ Mac

## ⛏️ Supported minecraft versions

* 📃 1.8.x-1.20.x

## Available languages

- **EN**
- **TR** (Coming soon)
- **ES** (Coming soon)
- **FR** (Coming soon)
- **SK** (Coming soon)
- **DE** (Coming soon)
- **PT** (Coming soon)
- **CAT** (Coming soon)

## Documentation

You can find the MCPTool documentation in the [docs folder](./docs).

## Download
All the information about the installation is [here](./docs/instalation.MD)

## 🕹 Usage
Use the `mcptool` command in the terminal.

## 🔗 Discord Server
Enter the discord server with this [link](https://discord.gg/TWKs6BWkR2)

## Minecraft Libraries Used
* Mineflayer [Github](https://github.com/PrismarineJS/mineflayer)
* Mcrcon [Github](https://github.com/uncaught-exceptions/mcrcon)

==> mcptool_py-1.0.9.tar.gz: mcptool_py-1.0.9/README.md <==
<h1 align="center"> 🧨 MCPTool v1.0.9
<h3 align="center"> Pentesting tool for Minecraft </h2>
<img align="center" src="https://i.imgur.com/GqkwN7v.png" alt="MCPTool" title="MCPTool" style="max-width: 100%; height: auto;">

<h4 align="center">This project was created for educational purposes and should not be used in environments without legal authorization.</p>

# 🛠 Features
* Get information from servers
* Get usernames or uuids from players
* Get information about IP addresses
* Get information about domains
* Get random servers using Seeker API (Shodan and Web Scraping will be included soon)
* Scan IP addresses (Nmap, Qubo, Masscan and others)
* Save players connecting to servers
* Easily create proxies (cascade and velocity)
* Create a fake proxy to capture data.
* Connect to a minecraft server using the terminal
* Send commands to servers using a bot
* Connect to the RCON of a server
* Perform a brute force attack on the RCON service
* Perform a brute force attack on the user of a non-premium/semi-premium server
* Kick players with bots thanks to 'You are logged in from a different location'
* Support for multiple languages.
* Search the password of a user using the nordify api.

## 💻 Supported operating systems:

* ✅ Windows (8, 8.1, 10 and 11)
* ✅ Linux
* ✅ Termux
* ✅ Mac

## ⛏️ Supported minecraft versions

* 📃 1.8.x-1.20.x

## Available languages

- **EN**
- **ES**
- **TR** (Coming soon)
- **FR** (Coming soon)
- **SK** (Coming soon)
- **DE** (Coming soon)
- **PT** (Coming soon)
- **CAT** (Coming soon)

## Documentation

You can find the MCPTool documentation in the [docs' folder](./docs).

## Download
All the information about the installation is [here](./docs/instalation)

## 🕹 Usage
Use the `mcptool` command in the terminal.

## 🔗 Discord Server
Enter the discord server with this [link](https://discord.gg/TWKs6BWkR2)

## Minecraft Libraries Used
* Mineflayer [Github](https://github.com/PrismarineJS/mineflayer)
* Mcrcon [Github](https://github.com/uncaught-exceptions/mcrcon)
